==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/glue/kotlin/inputs/CrawlerIcebergTargetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.glue.kotlin.inputs

import com.pulumi.aws.glue.inputs.CrawlerIcebergTargetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property connectionName The name of the connection to use to connect to the Iceberg target.
 * @property exclusions A list of glob patterns used to exclude from the crawl.
 * @property maximumTraversalDepth The maximum depth of Amazon S3 paths that the crawler can traverse to discover the Iceberg metadata folder in your Amazon S3 path. Used to limit the crawler run time. Valid values are between `1` and `20`.
 * @property paths One or more Amazon S3 paths that contains Iceberg metadata folders as s3://bucket/prefix.
 */
public data class CrawlerIcebergTargetArgs(
    public val connectionName: Output<String>? = null,
    public val exclusions: Output<List<String>>? = null,
    public val maximumTraversalDepth: Output<Int>,
    public val paths: Output<List<String>>,
) : ConvertibleToJava<com.pulumi.aws.glue.inputs.CrawlerIcebergTargetArgs> {
    override fun toJava(): com.pulumi.aws.glue.inputs.CrawlerIcebergTargetArgs =
        com.pulumi.aws.glue.inputs.CrawlerIcebergTargetArgs.builder()
            .connectionName(connectionName?.applyValue({ args0 -> args0 }))
            .exclusions(exclusions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .maximumTraversalDepth(maximumTraversalDepth.applyValue({ args0 -> args0 }))
            .paths(paths.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [CrawlerIcebergTargetArgs].
 */
@PulumiTagMarker
public class CrawlerIcebergTargetArgsBuilder internal constructor() {
    private var connectionName: Output<String>? = null

    private var exclusions: Output<List<String>>? = null

    private var maximumTraversalDepth: Output<Int>? = null

    private var paths: Output<List<String>>? = null

    /**
     * @param value The name of the connection to use to connect to the Iceberg target.
     */
    @JvmName("aigoiewmgkmlwnuy")
    public suspend fun connectionName(`value`: Output<String>) {
        this.connectionName = value
    }

    /**
     * @param value A list of glob patterns used to exclude from the crawl.
     */
    @JvmName("nuxhmrxuqaqqjdup")
    public suspend fun exclusions(`value`: Output<List<String>>) {
        this.exclusions = value
    }

    @JvmName("xhlbrsytnqhkgofi")
    public suspend fun exclusions(vararg values: Output<String>) {
        this.exclusions = Output.all(values.asList())
    }

    /**
     * @param values A list of glob patterns used to exclude from the crawl.
     */
    @JvmName("tdxsvhnxiopnyfyv")
    public suspend fun exclusions(values: List<Output<String>>) {
        this.exclusions = Output.all(values)
    }

    /**
     * @param value The maximum depth of Amazon S3 paths that the crawler can traverse to discover the Iceberg metadata folder in your Amazon S3 path. Used to limit the crawler run time. Valid values are between `1` and `20`.
     */
    @JvmName("dggoxkuhntuecfog")
    public suspend fun maximumTraversalDepth(`value`: Output<Int>) {
        this.maximumTraversalDepth = value
    }

    /**
     * @param value One or more Amazon S3 paths that contains Iceberg metadata folders as s3://bucket/prefix.
     */
    @JvmName("ixglmkflugwmfylg")
    public suspend fun paths(`value`: Output<List<String>>) {
        this.paths = value
    }

    @JvmName("gnkbirhtpejbncuc")
    public suspend fun paths(vararg values: Output<String>) {
        this.paths = Output.all(values.asList())
    }

    /**
     * @param values One or more Amazon S3 paths that contains Iceberg metadata folders as s3://bucket/prefix.
     */
    @JvmName("xdlgbmyhrgoebepu")
    public suspend fun paths(values: List<Output<String>>) {
        this.paths = Output.all(values)
    }

    /**
     * @param value The name of the connection to use to connect to the Iceberg target.
     */
    @JvmName("bpoaeogshnfctavq")
    public suspend fun connectionName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.connectionName = mapped
    }

    /**
     * @param value A list of glob patterns used to exclude from the crawl.
     */
    @JvmName("hhgceqprlswshhvf")
    public suspend fun exclusions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exclusions = mapped
    }

    /**
     * @param values A list of glob patterns used to exclude from the crawl.
     */
    @JvmName("mfsgntidgcxpwsto")
    public suspend fun exclusions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exclusions = mapped
    }

    /**
     * @param value The maximum depth of Amazon S3 paths that the crawler can traverse to discover the Iceberg metadata folder in your Amazon S3 path. Used to limit the crawler run time. Valid values are between `1` and `20`.
     */
    @JvmName("sfvtsfvescpvbdik")
    public suspend fun maximumTraversalDepth(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.maximumTraversalDepth = mapped
    }

    /**
     * @param value One or more Amazon S3 paths that contains Iceberg metadata folders as s3://bucket/prefix.
     */
    @JvmName("hbfrnmedbcpndxru")
    public suspend fun paths(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.paths = mapped
    }

    /**
     * @param values One or more Amazon S3 paths that contains Iceberg metadata folders as s3://bucket/prefix.
     */
    @JvmName("fcfkfakoydaygbjs")
    public suspend fun paths(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.paths = mapped
    }

    internal fun build(): CrawlerIcebergTargetArgs = CrawlerIcebergTargetArgs(
        connectionName = connectionName,
        exclusions = exclusions,
        maximumTraversalDepth = maximumTraversalDepth ?: throw
            PulumiNullFieldException("maximumTraversalDepth"),
        paths = paths ?: throw PulumiNullFieldException("paths"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/glue/kotlin/inputs/CrawlerIcebergTargetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.glue.kotlin.inputs

import com.pulumi.aws.glue.inputs.CrawlerIcebergTargetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property connectionName The name of the connection to use to connect to the Iceberg target.
 * @property exclusions A list of glob patterns used to exclude from the crawl.
 * @property maximumTraversalDepth The maximum depth of Amazon S3 paths that the crawler can traverse to discover the Iceberg metadata folder in your Amazon S3 path. Used to limit the crawler run time. Valid values are between `1` and `20`.
 * @property paths One or more Amazon S3 paths that contains Iceberg metadata folders as s3://bucket/prefix.
 */
public data class CrawlerIcebergTargetArgs(
    public val connectionName: Output<String>? = null,
    public val exclusions: Output<List<String>>? = null,
    public val maximumTraversalDepth: Output<Int>,
    public val paths: Output<List<String>>,
) : ConvertibleToJava<com.pulumi.aws.glue.inputs.CrawlerIcebergTargetArgs> {
    override fun toJava(): com.pulumi.aws.glue.inputs.CrawlerIcebergTargetArgs =
        com.pulumi.aws.glue.inputs.CrawlerIcebergTargetArgs.builder()
            .connectionName(connectionName?.applyValue({ args0 -> args0 }))
            .exclusions(exclusions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .maximumTraversalDepth(maximumTraversalDepth.applyValue({ args0 -> args0 }))
            .paths(paths.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [CrawlerIcebergTargetArgs].
 */
@PulumiTagMarker
public class CrawlerIcebergTargetArgsBuilder internal constructor() {
    private var connectionName: Output<String>? = null

    private var exclusions: Output<List<String>>? = null

    private var maximumTraversalDepth: Output<Int>? = null

    private var paths: Output<List<String>>? = null

    /**
     * @param value The name of the connection to use to connect to the Iceberg target.
     */
    @JvmName("vqdbpxitnchlwaff")
    public suspend fun connectionName(`value`: Output<String>) {
        this.connectionName = value
    }

    /**
     * @param value A list of glob patterns used to exclude from the crawl.
     */
    @JvmName("nmptjvjtwvcmuyls")
    public suspend fun exclusions(`value`: Output<List<String>>) {
        this.exclusions = value
    }

    @JvmName("rtadhscgkgnsukpn")
    public suspend fun exclusions(vararg values: Output<String>) {
        this.exclusions = Output.all(values.asList())
    }

    /**
     * @param values A list of glob patterns used to exclude from the crawl.
     */
    @JvmName("yqovdfyqdfjhkvnu")
    public suspend fun exclusions(values: List<Output<String>>) {
        this.exclusions = Output.all(values)
    }

    /**
     * @param value The maximum depth of Amazon S3 paths that the crawler can traverse to discover the Iceberg metadata folder in your Amazon S3 path. Used to limit the crawler run time. Valid values are between `1` and `20`.
     */
    @JvmName("owxujuyhjpefumrd")
    public suspend fun maximumTraversalDepth(`value`: Output<Int>) {
        this.maximumTraversalDepth = value
    }

    /**
     * @param value One or more Amazon S3 paths that contains Iceberg metadata folders as s3://bucket/prefix.
     */
    @JvmName("vyrhsejkidhfxhgu")
    public suspend fun paths(`value`: Output<List<String>>) {
        this.paths = value
    }

    @JvmName("danvvfvcfgqvridn")
    public suspend fun paths(vararg values: Output<String>) {
        this.paths = Output.all(values.asList())
    }

    /**
     * @param values One or more Amazon S3 paths that contains Iceberg metadata folders as s3://bucket/prefix.
     */
    @JvmName("yrcaacqihnkhuqoq")
    public suspend fun paths(values: List<Output<String>>) {
        this.paths = Output.all(values)
    }

    /**
     * @param value The name of the connection to use to connect to the Iceberg target.
     */
    @JvmName("eofvxbimxemkwbgs")
    public suspend fun connectionName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.connectionName = mapped
    }

    /**
     * @param value A list of glob patterns used to exclude from the crawl.
     */
    @JvmName("tuqhimxrebasfeis")
    public suspend fun exclusions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exclusions = mapped
    }

    /**
     * @param values A list of glob patterns used to exclude from the crawl.
     */
    @JvmName("xnbkrctffvvsqpob")
    public suspend fun exclusions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exclusions = mapped
    }

    /**
     * @param value The maximum depth of Amazon S3 paths that the crawler can traverse to discover the Iceberg metadata folder in your Amazon S3 path. Used to limit the crawler run time. Valid values are between `1` and `20`.
     */
    @JvmName("tqiirlvagpqgxfgk")
    public suspend fun maximumTraversalDepth(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.maximumTraversalDepth = mapped
    }

    /**
     * @param value One or more Amazon S3 paths that contains Iceberg metadata folders as s3://bucket/prefix.
     */
    @JvmName("tkvwbpahcsaapykb")
    public suspend fun paths(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.paths = mapped
    }

    /**
     * @param values One or more Amazon S3 paths that contains Iceberg metadata folders as s3://bucket/prefix.
     */
    @JvmName("xileupivyhxgfhnv")
    public suspend fun paths(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.paths = mapped
    }

    internal fun build(): CrawlerIcebergTargetArgs = CrawlerIcebergTargetArgs(
        connectionName = connectionName,
        exclusions = exclusions,
        maximumTraversalDepth = maximumTraversalDepth ?: throw
            PulumiNullFieldException("maximumTraversalDepth"),
        paths = paths ?: throw PulumiNullFieldException("paths"),
    )
}
